summaryrefslogtreecommitdiff
path: root/sw/source
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source')
-rw-r--r--sw/source/core/draw/dview.cxx2
-rw-r--r--sw/source/core/frmedt/fefly1.cxx2
-rw-r--r--sw/source/core/inc/dview.hxx10
-rw-r--r--sw/source/core/inc/layact.hxx12
-rw-r--r--sw/source/core/inc/viewimp.hxx24
-rw-r--r--sw/source/core/layout/flowfrm.cxx2
-rw-r--r--sw/source/core/layout/frmtool.cxx2
-rw-r--r--sw/source/core/layout/layact.cxx6
-rw-r--r--sw/source/core/layout/pagechg.cxx6
-rw-r--r--sw/source/core/layout/paintfrm.cxx2
-rw-r--r--sw/source/core/layout/wsfrm.cxx2
-rw-r--r--sw/source/core/view/vdraw.cxx16
-rw-r--r--sw/source/core/view/viewimp.cxx54
-rw-r--r--sw/source/core/view/vnew.cxx4
14 files changed, 72 insertions, 72 deletions
diff --git a/sw/source/core/draw/dview.cxx b/sw/source/core/draw/dview.cxx
index b7f28fcb6bd4..a3b14905b15b 100644
--- a/sw/source/core/draw/dview.cxx
+++ b/sw/source/core/draw/dview.cxx
@@ -92,7 +92,7 @@ static const SwFrm *lcl_FindAnchor( const SdrObject *pObj, bool bAll )
return 0;
}
-SwDrawView::SwDrawView( SwViewImp &rI, SdrModel *pMd, OutputDevice *pOutDev) :
+SwDrawView::SwDrawView( SwViewShellImp &rI, SdrModel *pMd, OutputDevice *pOutDev) :
FmFormView( static_cast<FmFormModel*>(pMd), pOutDev ),
rImp( rI )
{
diff --git a/sw/source/core/frmedt/fefly1.cxx b/sw/source/core/frmedt/fefly1.cxx
index 48f78e60197c..ab8f8fd9f4e7 100644
--- a/sw/source/core/frmedt/fefly1.cxx
+++ b/sw/source/core/frmedt/fefly1.cxx
@@ -232,7 +232,7 @@ void SwFEShell::SelectFlyFrm( SwFlyFrm& rFrm, bool bNew )
// not have been changed
// The frames should not be selected by the document position, because
// it should have been selected!
- SwViewImp *pImpl = Imp();
+ SwViewShellImp *pImpl = Imp();
if( GetWin() && (bNew || !pImpl->GetDrawView()->AreObjectsMarked()) )
{
OSL_ENSURE( rFrm.IsFlyFrm(), "SelectFlyFrm will einen Fly" );
diff --git a/sw/source/core/inc/dview.hxx b/sw/source/core/inc/dview.hxx
index 4c5ec084dcb1..b8fce60b62f9 100644
--- a/sw/source/core/inc/dview.hxx
+++ b/sw/source/core/inc/dview.hxx
@@ -22,7 +22,7 @@
#include <svx/fmview.hxx>
class OutputDevice;
-class SwViewImp;
+class SwViewShellImp;
class SwFrm;
class SwFlyFrm;
class SwAnchoredObject;
@@ -31,7 +31,7 @@ class SdrUndoManager;
class SwDrawView : public FmFormView
{
Point aAnchorPoint; // anchor position
- SwViewImp &rImp; // a view is always part of a shell
+ SwViewShellImp &rImp; // a view is always part of a shell
const SwFrm *CalcAnchor();
@@ -79,7 +79,7 @@ protected:
virtual SdrUndoManager* getSdrUndoManagerForEnhancedTextEdit() const SAL_OVERRIDE;
public:
- SwDrawView( SwViewImp &rI, SdrModel *pMd, OutputDevice* pOutDev=NULL );
+ SwDrawView( SwViewShellImp &rI, SdrModel *pMd, OutputDevice* pOutDev=NULL );
// from base class
virtual SdrObject* GetMaxToTopObj(SdrObject* pObj) const SAL_OVERRIDE;
@@ -96,8 +96,8 @@ public:
virtual void MakeVisible( const Rectangle&, vcl::Window &rWin ) SAL_OVERRIDE;
virtual void CheckPossibilities() SAL_OVERRIDE;
- const SwViewImp &Imp() const { return rImp; }
- SwViewImp &Imp() { return rImp; }
+ const SwViewShellImp &Imp() const { return rImp; }
+ SwViewShellImp &Imp() { return rImp; }
// anchor and Xor for dragging
void ShowDragAnchor();
diff --git a/sw/source/core/inc/viewimp.hxx b/sw/source/core/inc/viewimp.hxx
index 8c64a8d5d5e3..923eee01a7f2 100644
--- a/sw/source/core/inc/viewimp.hxx
+++ b/sw/source/core/inc/viewimp.hxx
@@ -51,7 +51,7 @@ namespace sdr { namespace contact {
} }
// <--
-class SwViewImp
+class SwViewShellImp
{
friend class SwViewShell;
@@ -136,8 +136,8 @@ private:
void _InvalidateAccessibleParaAttrs( const SwTxtFrm& rTxtFrm );
public:
- SwViewImp( SwViewShell * );
- ~SwViewImp();
+ SwViewShellImp( SwViewShell * );
+ ~SwViewShellImp();
void Init( const SwViewOption * ); /// Only for SwViewShell::Init()
const SwViewShell *GetShell() const { return pSh; }
@@ -272,21 +272,21 @@ public:
void FireAccessibleEvents();
};
-inline SwPageFrm *SwViewImp::GetFirstVisPage()
+inline SwPageFrm *SwViewShellImp::GetFirstVisPage()
{
if ( bFirstPageInvalid )
SetFirstVisPage();
return pFirstVisPage;
}
-inline const SwPageFrm *SwViewImp::GetFirstVisPage() const
+inline const SwPageFrm *SwViewShellImp::GetFirstVisPage() const
{
if ( bFirstPageInvalid )
- const_cast<SwViewImp*>(this)->SetFirstVisPage();
+ const_cast<SwViewShellImp*>(this)->SetFirstVisPage();
return pFirstVisPage;
}
-inline SwAccessibleMap& SwViewImp::GetAccessibleMap()
+inline SwAccessibleMap& SwViewShellImp::GetAccessibleMap()
{
if( !pAccMap )
CreateAccessibleMap();
@@ -294,30 +294,30 @@ inline SwAccessibleMap& SwViewImp::GetAccessibleMap()
return *pAccMap;
}
-inline void SwViewImp::DisposeAccessibleFrm( const SwFrm *pFrm,
+inline void SwViewShellImp::DisposeAccessibleFrm( const SwFrm *pFrm,
bool bRecursive )
{
DisposeAccessible( pFrm, 0, bRecursive );
}
-inline void SwViewImp::DisposeAccessibleObj( const SdrObject *pObj )
+inline void SwViewShellImp::DisposeAccessibleObj( const SdrObject *pObj )
{
DisposeAccessible( 0, pObj, false );
}
-inline void SwViewImp::MoveAccessibleFrm( const SwFrm *pFrm,
+inline void SwViewShellImp::MoveAccessibleFrm( const SwFrm *pFrm,
const SwRect& rOldFrm )
{
MoveAccessible( pFrm, 0, rOldFrm );
}
-inline void SwViewImp::AddAccessibleFrm( const SwFrm *pFrm )
+inline void SwViewShellImp::AddAccessibleFrm( const SwFrm *pFrm )
{
SwRect aEmptyRect;
MoveAccessible( pFrm, 0, aEmptyRect );
}
-inline void SwViewImp::AddAccessibleObj( const SdrObject *pObj )
+inline void SwViewShellImp::AddAccessibleObj( const SdrObject *pObj )
{
SwRect aEmptyRect;
MoveAccessible( 0, pObj, aEmptyRect );
diff --git a/sw/source/core/layout/flowfrm.cxx b/sw/source/core/layout/flowfrm.cxx
index 1094fcf7da82..915c60a06152 100644
--- a/sw/source/core/layout/flowfrm.cxx
+++ b/sw/source/core/layout/flowfrm.cxx
@@ -548,7 +548,7 @@ void SwFlowFrm::MoveSubTree( SwLayoutFrm* pParent, SwFrm* pSibling )
// Be economical with notifications if an action is running.
SwViewShell *pSh = m_rThis.getRootFrm()->GetCurrShell();
- const SwViewImp *pImp = pSh ? pSh->Imp() : 0;
+ const SwViewShellImp *pImp = pSh ? pSh->Imp() : 0;
const bool bComplete = pImp && pImp->IsAction() && pImp->GetLayAction().IsComplete();
if ( !bComplete )
diff --git a/sw/source/core/layout/frmtool.cxx b/sw/source/core/layout/frmtool.cxx
index 7145ef760b24..0fafeb2f8023 100644
--- a/sw/source/core/layout/frmtool.cxx
+++ b/sw/source/core/layout/frmtool.cxx
@@ -647,7 +647,7 @@ SwFlyNotify::~SwFlyNotify()
if ( pFly->IsNotifyBack() )
{
SwViewShell *pSh = pFly->getRootFrm()->GetCurrShell();
- SwViewImp *pImp = pSh ? pSh->Imp() : 0;
+ SwViewShellImp *pImp = pSh ? pSh->Imp() : 0;
if ( !pImp || !pImp->IsAction() || !pImp->GetLayAction().IsAgain() )
{
//If in the LayAction the IsAgain is set it can be
diff --git a/sw/source/core/layout/layact.cxx b/sw/source/core/layout/layact.cxx
index 71093be75c76..f4f8512b1e21 100644
--- a/sw/source/core/layout/layact.cxx
+++ b/sw/source/core/layout/layact.cxx
@@ -276,7 +276,7 @@ void SwLayAction::PaintCntnt( const SwCntntFrm *pCnt,
}
}
-SwLayAction::SwLayAction( SwRootFrm *pRt, SwViewImp *pI ) :
+SwLayAction::SwLayAction( SwRootFrm *pRt, SwViewShellImp *pI ) :
pRoot( pRt ),
pImp( pI ),
pOptTab( 0 ),
@@ -2120,7 +2120,7 @@ void SwLayIdle::ShowIdle( ColorData eColorData )
#define SHOW_IDLE( ColorData )
#endif // DBG_UTIL
-SwLayIdle::SwLayIdle( SwRootFrm *pRt, SwViewImp *pI ) :
+SwLayIdle::SwLayIdle( SwRootFrm *pRt, SwViewShellImp *pI ) :
pRoot( pRt ),
pImp( pI )
#ifdef DBG_UTIL
@@ -2219,7 +2219,7 @@ SwLayIdle::SwLayIdle( SwRootFrm *pRt, SwViewImp *pI ) :
// the whole window. Otherwise there would arise paint problems whose
// solution would be disproportionally expensive.
//fix(18176):
- SwViewImp *pViewImp = rSh.Imp();
+ SwViewShellImp *pViewImp = rSh.Imp();
bool bUnlock = false;
if ( pViewImp->GetRegion() )
{
diff --git a/sw/source/core/layout/pagechg.cxx b/sw/source/core/layout/pagechg.cxx
index 66e85f4225c9..60c1f06f9d82 100644
--- a/sw/source/core/layout/pagechg.cxx
+++ b/sw/source/core/layout/pagechg.cxx
@@ -250,7 +250,7 @@ SwPageFrm::~SwPageFrm()
{
if ( pSh )
{
- SwViewImp *pImp = pSh->Imp();
+ SwViewShellImp *pImp = pSh->Imp();
pImp->SetFirstVisPageInvalid();
if ( pImp->IsAction() )
pImp->GetLayAction().SetAgain();
@@ -951,7 +951,7 @@ void SwFrm::CheckPageDescs( SwPageFrm *pStart, bool bNotifyFields, SwPageFrm** p
assert(pStart && "no starting page.");
SwViewShell *pSh = pStart->getRootFrm()->GetCurrShell();
- SwViewImp *pImp = pSh ? pSh->Imp() : 0;
+ SwViewShellImp *pImp = pSh ? pSh->Imp() : 0;
if ( pImp && pImp->IsAction() && !pImp->GetLayAction().IsCheckPages() )
{
@@ -1217,7 +1217,7 @@ SwPageFrm *SwFrm::InsertPage( SwPageFrm *pPrevPage, bool bFtn )
{
CheckPageDescs( pSibling, false );
SwViewShell *pSh = getRootFrm()->GetCurrShell();
- SwViewImp *pImp = pSh ? pSh->Imp() : 0;
+ SwViewShellImp *pImp = pSh ? pSh->Imp() : 0;
if ( pImp && pImp->IsAction() && !pImp->GetLayAction().IsCheckPages() )
{
const sal_uInt16 nNum = pImp->GetLayAction().GetCheckPageNum();
diff --git a/sw/source/core/layout/paintfrm.cxx b/sw/source/core/layout/paintfrm.cxx
index 0c95140f81ee..4c266a2a5445 100644
--- a/sw/source/core/layout/paintfrm.cxx
+++ b/sw/source/core/layout/paintfrm.cxx
@@ -7688,7 +7688,7 @@ Graphic SwFlyFrmFmt::MakeGraphic( ImageMap* pMap )
gProp.bSFlyMetafile = true;
gProp.pSFlyMetafileOut = pWin;
- SwViewImp *pImp = pSh->Imp();
+ SwViewShellImp *pImp = pSh->Imp();
gProp.pSFlyOnlyDraw = pFly;
gProp.pSLines = new SwLineRects;
diff --git a/sw/source/core/layout/wsfrm.cxx b/sw/source/core/layout/wsfrm.cxx
index 3b2abee8af60..aa6e9f818c78 100644
--- a/sw/source/core/layout/wsfrm.cxx
+++ b/sw/source/core/layout/wsfrm.cxx
@@ -3178,7 +3178,7 @@ void SwLayoutFrm::FormatWidthCols( const SwBorderAttrs &rAttrs,
bool bEnd = false;
bool bBackLock = false;
SwViewShell *pSh = getRootFrm()->GetCurrShell();
- SwViewImp *pImp = pSh ? pSh->Imp() : 0;
+ SwViewShellImp *pImp = pSh ? pSh->Imp() : 0;
{
// Underlying algorithm
// We try to find the optimal height for the column.
diff --git a/sw/source/core/view/vdraw.cxx b/sw/source/core/view/vdraw.cxx
index f59a8ca9a219..9d808613653a 100644
--- a/sw/source/core/view/vdraw.cxx
+++ b/sw/source/core/view/vdraw.cxx
@@ -43,7 +43,7 @@
#include <IDocumentDrawModelAccess.hxx>
-void SwViewImp::StartAction()
+void SwViewShellImp::StartAction()
{
if ( HasDrawView() )
{
@@ -53,7 +53,7 @@ void SwViewImp::StartAction()
}
}
-void SwViewImp::EndAction()
+void SwViewShellImp::EndAction()
{
if ( HasDrawView() )
{
@@ -63,7 +63,7 @@ void SwViewImp::EndAction()
}
}
-void SwViewImp::LockPaint()
+void SwViewShellImp::LockPaint()
{
if ( HasDrawView() )
{
@@ -76,13 +76,13 @@ void SwViewImp::LockPaint()
}
}
-void SwViewImp::UnlockPaint()
+void SwViewShellImp::UnlockPaint()
{
if ( bResetHdlHiddenPaint )
GetDrawView()->showMarkHandles();
}
-void SwViewImp::PaintLayer( const SdrLayerID _nLayerID,
+void SwViewShellImp::PaintLayer( const SdrLayerID _nLayerID,
SwPrintData const*const pPrintData,
const SwRect& aPaintRect,
const Color* _pPageBackgrdColor,
@@ -115,7 +115,7 @@ void SwViewImp::PaintLayer( const SdrLayerID _nLayerID,
(_nLayerID == pIDDMA->GetHeavenId()) )
{
OSL_ENSURE( _pPageBackgrdColor,
- "incorrect usage of SwViewImp::PaintLayer: pPageBackgrdColor have to be set for painting layer <hell> or <heaven>");
+ "incorrect usage of SwViewShellImp::PaintLayer: pPageBackgrdColor have to be set for painting layer <hell> or <heaven>");
if ( _pPageBackgrdColor )
{
aOldOutlinerBackgrdColor =
@@ -154,7 +154,7 @@ void SwViewImp::PaintLayer( const SdrLayerID _nLayerID,
#define FUZZY_EDGE 400
-bool SwViewImp::IsDragPossible( const Point &rPoint )
+bool SwViewShellImp::IsDragPossible( const Point &rPoint )
{
if ( !HasDrawView() )
return false;
@@ -183,7 +183,7 @@ bool SwViewImp::IsDragPossible( const Point &rPoint )
return aRect.IsInside( rPoint );
}
-void SwViewImp::NotifySizeChg( const Size &rNewSz )
+void SwViewShellImp::NotifySizeChg( const Size &rNewSz )
{
if ( !HasDrawView() )
return;
diff --git a/sw/source/core/view/viewimp.cxx b/sw/source/core/view/viewimp.cxx
index 35805bf8081b..c2f7feefc112 100644
--- a/sw/source/core/view/viewimp.cxx
+++ b/sw/source/core/view/viewimp.cxx
@@ -41,9 +41,9 @@
#include <IDocumentSettingAccess.hxx>
#include <drawdoc.hxx>
-void SwViewImp::Init( const SwViewOption *pNewOpt )
+void SwViewShellImp::Init( const SwViewOption *pNewOpt )
{
- OSL_ENSURE( pDrawView, "SwViewImp::Init without DrawView" );
+ OSL_ENSURE( pDrawView, "SwViewShellImp::Init without DrawView" );
//Create PageView if it doesn't exist
SwRootFrm *pRoot = pSh->GetLayout();
if ( !pSdrPageView )
@@ -86,7 +86,7 @@ void SwViewImp::Init( const SwViewOption *pNewOpt )
}
/// CTor for the core internals
-SwViewImp::SwViewImp( SwViewShell *pParent ) :
+SwViewShellImp::SwViewShellImp( SwViewShell *pParent ) :
pSh( pParent ),
pDrawView( 0 ),
pSdrPageView( 0 ),
@@ -106,7 +106,7 @@ SwViewImp::SwViewImp( SwViewShell *pParent ) :
{
}
-SwViewImp::~SwViewImp()
+SwViewShellImp::~SwViewShellImp()
{
delete pAccMap;
@@ -125,12 +125,12 @@ SwViewImp::~SwViewImp()
OSL_ENSURE( !pIdleAct,"Be idle for the rest of your life." );
}
-void SwViewImp::DelRegion()
+void SwViewShellImp::DelRegion()
{
DELETEZ(pRegion);
}
-bool SwViewImp::AddPaintRect( const SwRect &rRect )
+bool SwViewShellImp::AddPaintRect( const SwRect &rRect )
{
// In case of tiled rendering the visual area is the last painted tile -> not interesting.
if ( rRect.IsOver( pSh->VisArea() ) || pSh->isTiledRendering() )
@@ -148,18 +148,18 @@ bool SwViewImp::AddPaintRect( const SwRect &rRect )
return false;
}
-void SwViewImp::CheckWaitCrsr()
+void SwViewShellImp::CheckWaitCrsr()
{
if ( pLayAct )
pLayAct->CheckWaitCrsr();
}
-bool SwViewImp::IsCalcLayoutProgress() const
+bool SwViewShellImp::IsCalcLayoutProgress() const
{
return pLayAct && pLayAct->IsCalcLayout();
}
-bool SwViewImp::IsUpdateExpFlds()
+bool SwViewShellImp::IsUpdateExpFlds()
{
if ( pLayAct && pLayAct->IsCalcLayout() )
{
@@ -169,7 +169,7 @@ bool SwViewImp::IsUpdateExpFlds()
return false;
}
-void SwViewImp::SetFirstVisPage()
+void SwViewShellImp::SetFirstVisPage()
{
if ( pSh->mbDocSizeChgd && pSh->VisArea().Top() > pSh->GetLayout()->Frm().Height() )
{
@@ -205,7 +205,7 @@ void SwViewImp::SetFirstVisPage()
bFirstPageInvalid = false;
}
-void SwViewImp::MakeDrawView()
+void SwViewShellImp::MakeDrawView()
{
IDocumentDrawModelAccess* pIDDMA = GetShell()->getIDocumentDrawModelAccess();
@@ -251,7 +251,7 @@ void SwViewImp::MakeDrawView()
}
}
-Color SwViewImp::GetRetoucheColor() const
+Color SwViewShellImp::GetRetoucheColor() const
{
Color aRet( COL_TRANSPARENT );
const SwViewShell &rSh = *GetShell();
@@ -270,14 +270,14 @@ Color SwViewImp::GetRetoucheColor() const
}
// create page preview layout
-void SwViewImp::InitPagePreviewLayout()
+void SwViewShellImp::InitPagePreviewLayout()
{
OSL_ENSURE( pSh->GetLayout(), "no layout - page preview layout can not be created.");
if ( pSh->GetLayout() )
mpPgPreviewLayout = new SwPagePreviewLayout( *pSh, *(pSh->GetLayout()) );
}
-void SwViewImp::UpdateAccessible()
+void SwViewShellImp::UpdateAccessible()
{
// We require a layout and an XModel to be accessible.
IDocumentLayoutAccess* pIDLA = GetShell()->getIDocumentLayoutAccess();
@@ -289,7 +289,7 @@ void SwViewImp::UpdateAccessible()
GetAccessibleMap().GetDocumentView();
}
-void SwViewImp::DisposeAccessible( const SwFrm *pFrm,
+void SwViewShellImp::DisposeAccessible( const SwFrm *pFrm,
const SdrObject *pObj,
bool bRecursive )
{
@@ -301,7 +301,7 @@ void SwViewImp::DisposeAccessible( const SwFrm *pFrm,
}
}
-void SwViewImp::MoveAccessible( const SwFrm *pFrm, const SdrObject *pObj,
+void SwViewShellImp::MoveAccessible( const SwFrm *pFrm, const SdrObject *pObj,
const SwRect& rOldFrm )
{
OSL_ENSURE( !pFrm || pFrm->IsAccessibleFrm(), "frame is not accessible" );
@@ -313,7 +313,7 @@ void SwViewImp::MoveAccessible( const SwFrm *pFrm, const SdrObject *pObj,
}
}
-void SwViewImp::InvalidateAccessibleFrmContent( const SwFrm *pFrm )
+void SwViewShellImp::InvalidateAccessibleFrmContent( const SwFrm *pFrm )
{
OSL_ENSURE( pFrm->IsAccessibleFrm(), "frame is not accessible" );
for(SwViewShell& rTmp : GetShell()->GetRingContainer())
@@ -323,13 +323,13 @@ void SwViewImp::InvalidateAccessibleFrmContent( const SwFrm *pFrm )
}
}
-void SwViewImp::InvalidateAccessibleCursorPosition( const SwFrm *pFrm )
+void SwViewShellImp::InvalidateAccessibleCursorPosition( const SwFrm *pFrm )
{
if( IsAccessible() )
GetAccessibleMap().InvalidateCursorPosition( pFrm );
}
-void SwViewImp::InvalidateAccessibleEditableState( bool bAllShells,
+void SwViewShellImp::InvalidateAccessibleEditableState( bool bAllShells,
const SwFrm *pFrm )
{
if( bAllShells )
@@ -346,7 +346,7 @@ void SwViewImp::InvalidateAccessibleEditableState( bool bAllShells,
}
}
-void SwViewImp::InvalidateAccessibleRelationSet( const SwFlyFrm *pMaster,
+void SwViewShellImp::InvalidateAccessibleRelationSet( const SwFlyFrm *pMaster,
const SwFlyFrm *pFollow )
{
for(SwViewShell& rTmp : GetShell()->GetRingContainer())
@@ -358,7 +358,7 @@ void SwViewImp::InvalidateAccessibleRelationSet( const SwFlyFrm *pMaster,
}
/// invalidate CONTENT_FLOWS_FROM/_TO relation for paragraphs
-void SwViewImp::_InvalidateAccessibleParaFlowRelation( const SwTxtFrm* _pFromTxtFrm,
+void SwViewShellImp::_InvalidateAccessibleParaFlowRelation( const SwTxtFrm* _pFromTxtFrm,
const SwTxtFrm* _pToTxtFrm )
{
if ( !_pFromTxtFrm && !_pToTxtFrm )
@@ -386,7 +386,7 @@ void SwViewImp::_InvalidateAccessibleParaFlowRelation( const SwTxtFrm* _pFromTxt
}
/// invalidate text selection for paragraphs
-void SwViewImp::_InvalidateAccessibleParaTextSelection()
+void SwViewShellImp::_InvalidateAccessibleParaTextSelection()
{
for(SwViewShell& rTmp : GetShell()->GetRingContainer())
{
@@ -398,7 +398,7 @@ void SwViewImp::_InvalidateAccessibleParaTextSelection()
}
/// invalidate attributes for paragraphs
-void SwViewImp::_InvalidateAccessibleParaAttrs( const SwTxtFrm& rTxtFrm )
+void SwViewShellImp::_InvalidateAccessibleParaAttrs( const SwTxtFrm& rTxtFrm )
{
for(SwViewShell& rTmp : GetShell()->GetRingContainer())
{
@@ -410,7 +410,7 @@ void SwViewImp::_InvalidateAccessibleParaAttrs( const SwTxtFrm& rTxtFrm )
}
// OD 15.01.2003 #103492# - method signature change due to new page preview functionality
-void SwViewImp::UpdateAccessiblePreview( const std::vector<PreviewPage*>& _rPreviewPages,
+void SwViewShellImp::UpdateAccessiblePreview( const std::vector<PreviewPage*>& _rPreviewPages,
const Fraction& _rScale,
const SwPageFrm* _pSelectedPageFrm,
const Size& _rPreviewWinSize )
@@ -420,20 +420,20 @@ void SwViewImp::UpdateAccessiblePreview( const std::vector<PreviewPage*>& _rPrev
_pSelectedPageFrm, _rPreviewWinSize );
}
-void SwViewImp::InvalidateAccessiblePreviewSelection( sal_uInt16 nSelPage )
+void SwViewShellImp::InvalidateAccessiblePreviewSelection( sal_uInt16 nSelPage )
{
if( IsAccessible() )
GetAccessibleMap().InvalidatePreviewSelection( nSelPage );
}
-SwAccessibleMap *SwViewImp::CreateAccessibleMap()
+SwAccessibleMap *SwViewShellImp::CreateAccessibleMap()
{
OSL_ENSURE( !pAccMap, "accessible map exists" );
pAccMap = new SwAccessibleMap( GetShell() );
return pAccMap;
}
-void SwViewImp::FireAccessibleEvents()
+void SwViewShellImp::FireAccessibleEvents()
{
if( IsAccessible() )
GetAccessibleMap().FireEvents();
diff --git a/sw/source/core/view/vnew.cxx b/sw/source/core/view/vnew.cxx
index d4813f9e594b..78911491aaf5 100644
--- a/sw/source/core/view/vnew.cxx
+++ b/sw/source/core/view/vnew.cxx
@@ -151,7 +151,7 @@ SwViewShell::SwViewShell( SwDoc& rDocument, vcl::Window *pWindow,
:
maBrowseBorder(),
mpSfxViewShell( 0 ),
- mpImp( new SwViewImp( this ) ),
+ mpImp( new SwViewShellImp( this ) ),
mpWin( pWindow ),
mpOut( pOutput ? pOutput
: pWindow ? (OutputDevice*)pWindow
@@ -230,7 +230,7 @@ SwViewShell::SwViewShell( SwViewShell& rShell, vcl::Window *pWindow,
Ring( &rShell ),
maBrowseBorder( rShell.maBrowseBorder ),
mpSfxViewShell( 0 ),
- mpImp( new SwViewImp( this ) ),
+ mpImp( new SwViewShellImp( this ) ),
mpWin( pWindow ),
mpOut( pOutput ? pOutput
: pWindow ? (OutputDevice*)pWindow
diff --git a/sw/source/core/inc/layact.hxx b/sw/source/core/inc/layact.hxx
index a3c4e7ca74d0..96bf9a10bbe6 100644
--- a/sw/source/core/inc/layact.hxx
+++ b/sw/source/core/inc/layact.hxx
@@ -32,7 +32,7 @@ class SwPageFrm;
class SwFlyFrm;
class SwCntntFrm;
class SwTabFrm;
-class SwViewImp;
+class SwViewShellImp;
class SwCntntNode;
class SwWait;
@@ -44,14 +44,14 @@ class SwWait;
* 3. Calling Action()
* 4. Soon after that the destruction of the object
*
* The object registers at the SwViewImp in the ctor and deregisters not until
* the dtor!
* It's a typical stack object.
*/
class SwLayAction
{
SwRootFrm *pRoot;
- SwViewImp *pImp; // here the action logs in and off
+ SwViewShellImp *pImp; // here the action logs in and off
// For the sake of optimization, so that the tables stick a bit better to
// the Crsr when hitting return/backspace in front of one.
@@ -119,7 +119,7 @@ class SwLayAction
inline std::clock_t GetStartTicks() { return nStartTicks; }
public:
- SwLayAction( SwRootFrm *pRt, SwViewImp *pImp );
+ SwLayAction( SwRootFrm *pRt, SwViewShellImp *pImp );
~SwLayAction();
void SetIdle ( bool bNew ) { bIdle = bNew; }
@@ -182,7 +182,7 @@ class SwLayIdle
{
SwRootFrm *pRoot;
- SwViewImp *pImp; // The Idler registers and deregisters here
+ SwViewShellImp *pImp; // The Idler registers and deregisters here
SwCntntNode *pCntntNode; // The current cursor position is saved here
sal_Int32 nTxtPos;
bool bPageValid; // Were we able to evaluate everything on the whole page?
@@ -201,7 +201,7 @@ class SwLayIdle
bool DoIdleJob( IdleJobType, bool bVisAreaOnly );
public:
- SwLayIdle( SwRootFrm *pRt, SwViewImp *pImp );
+ SwLayIdle( SwRootFrm *pRt, SwViewShellImp *pImp );
~SwLayIdle();
};
@@ -44,14 +44,14 @@ class SwWait;
* 4. Soon after that the destruction of the object
*
- * The object registers at the SwViewImp in the ctor and deregisters not until
+ * The object registers at the SwViewShellImp in the ctor and deregisters not until
* the dtor!
* It's a typical stack object.